@@ -19,6 +19,8 @@ require 'tempfile'
 require 'time'
 require 'yaml'
 
+require 'gem2deb/package_name_mapping'
+
 module Gem2Deb
   class Metadata
 
@@ -99,6 +101,10 @@ module Gem2Deb
       end
     end
 
+    def get_debian_dependencies(global = true)
+      calculate_debian_dependencies!
+    end
+
     protected
 
     def load_gemspec
@@ -202,5 +208,28 @@ module Gem2Deb
       end
     end
 
+    def calculate_debian_dependencies!(global = true)
+      gem_to_package = Gem2Deb::PackageNameMapping.new(global)
+      result = []
+      if executables && executables.size > 0
+        result << 'ruby | ruby-interpreter'
+      end
+      dependencies.select do |dep|
+        dep.type == :runtime
+      end.each do |dep|
+        dependency = gem_to_package[dep.name]
+        version = dep.requirement.to_s
+        if version == '>= 0'
+          result << dependency
+        else
+          dep.requirements_list.each do |v|
+            spec = v.gsub('~>', '>=').gsub(/>(\s+)/, '>>\1').gsub(/<(\s+)/, '<<\1').gsub(/^=(\s+)/, '>=\1')
+            result << ('%s (%s)' % [dependency, spec])
+          end
+        end
+      end
+      result
+    end
+
   end
 end
