@@ -55,6 +55,16 @@ class DhMakeRubyTest < Gem2DebTestCase
     assert_equal @dh_make_ruby.itp_bug, '#42'
   end
 
+  should 'not make libraries depend on ruby' do
+    dh_make_ruby = Gem2Deb::DhMakeRuby.new(SIMPLE_GEM_SOURCE)
+    assert_not_include dh_make_ruby.binary_package.dependencies, 'ruby | ruby-interpreter'
+  end
+
+  should 'make programs depend on ruby' do
+    dh_make_ruby = Gem2Deb::DhMakeRuby.new(SIMPLE_PROGRAM_SOURCE)
+    assert_include dh_make_ruby.binary_package.dependencies, 'ruby | ruby-interpreter'
+  end
+
   context 'simple gem' do
     %w[
       debian/control
@@ -74,6 +84,11 @@ class DhMakeRubyTest < Gem2DebTestCase
     end
   end
 
+  should 'produce debian/copyright with FIXMEs in it' do
+    copyright = File.read(File.join(DEBIANIZED_SIMPLE_GEM, 'debian/copyright'))
+    assert copyright =~ /FIXME/
+  end
+
   DEBIANIZED_SIMPLE_EXTENSION       = File.join(tmpdir, 'ruby-' + SIMPLE_EXTENSION_DIRNAME)
   SIMPLE_EXTENSION_UPSTREAM_TARBALL = DEBIANIZED_SIMPLE_EXTENSION + '.tar.gz'
   one_time_setup do
@@ -136,44 +151,6 @@ class DhMakeRubyTest < Gem2DebTestCase
     end
   end
 
-  context 'dependencies' do
-    setup do
-      file = File.join(DEBIANIZED_SIMPLE_GEM, 'debian/control')
-      deps = `grep-dctrl -sDepends -n '' #{file}`
-      @dependencies = deps.strip.split(/\s*,\s*/)
-    end
-    should 'get simple dependency' do
-      assert_include @dependencies, 'ruby-dep'
-    end
-    should 'not use dependencies with exact versions' do
-      assert_include @dependencies, 'ruby-depwithversion (>= 1.0)'
-    end
-    should 'get version with spermy' do
-      assert_include @dependencies, 'ruby-depwithspermy (>= 1.0)'
-    end
-    should 'get version with >' do
-      assert_include @dependencies, 'ruby-depwithgt (>> 1.0)'
-    end
-    should 'get version with two requirements' do
-      assert_include @dependencies, 'ruby-depwith2versions (>= 1.0)'
-      assert_include @dependencies, 'ruby-depwith2versions (<< 2.0)'
-    end
-  end
-
-  context 'converting gem name to package name without a cache' do
-    {
-      'foo' => 'ruby-foo',
-      'foo-bar_baz' => 'ruby-foo-bar-baz',
-    }.each do |input,output|
-      setup do
-        @dh_make_ruby = Gem2Deb::DhMakeRuby.new('.')
-      end
-      should "convert #{input} to #{output}" do
-        assert_equal output, @dh_make_ruby.gem_name_to_source_package_name(input)
-      end
-    end
-  end
-
   context 'dh-make-ruby --overwrite' do
     setup do
       @pwd = Dir.pwd
